from .files import FileClient


def show(gcs_path):
    """
    Backported dapla function to support a simplified list of files or folders for a given GCS path
    :param gcs_path: path or paths to the file(s) you want to get the contents of
    :return: a simplified list of files or folders
    """
    fs = FileClient.get_gcs_file_system()
    return list(map(lambda o:  _trimmed_name(o), fs.ls(gcs_path, detail=True)))


def details(gcs_path):
    """
    Backported dapla function to support detailed list of files or folders for a given GCS path
    :param gcs_path: path or paths to the file(s) you want to get the contents of
    :return: a detailed list of files or folders
    """
    fs = FileClient.get_gcs_file_system()
    return list(map(lambda o: _folder_item(o) if o['storageClass'] == 'DIRECTORY' else _file_item(o),
                    fs.ls(gcs_path, detail=True)))


def _trimmed_name(o):
    return o['name'].lstrip(o['bucket'])


def _folder_item(o):
    return {'Size': o['size'], 'Name': _trimmed_name(o)}


def _file_item(o):
    return {'Size': o['size'], 'Name': _trimmed_name(o), 'Created': o['timeCreated'], 'Updated': o['updated']}





import pathlib
from setuptools import setup
from setuptools import find_packages

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setup(
    name="dapla-toolbelt",
    version="1.1.2",
    license='Apache Software License',
    description="Python module for use within Jupyterlab notebooks, specifically aimed for Statistics Norway's data "
                "platform called Dapla",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/statisticsnorway/dapla-toolbelt",
    author="Statistics Norway",
    author_email="old@ssb.no",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.9",
    ],
    packages=find_packages(exclude=('tests', 'examples',)),
    include_package_data=True,
    install_requires=["pandas", "jupyterhub", "gcsfs", "ipython", "lxml"],
)
